bayespy.nodes.GaussianWishart.lower_bound_contribution
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianWishart.lower_bound_contribution